@@ -117,7 +117,7 @@ namespace Sass {
     if (sel) sel = sel->eval(eval);
 
     // check for parent selectors in base level rules
-    if (r->is_root()) {
+    if (r->is_root() || (block_stack.back() && block_stack.back()->is_root())) {
       if (Selector_List_Ptr selector_list = Cast<Selector_List>(r->selector())) {
         for (auto __complex_selector = (selector_list->elements()).begin(); __complex_selector != (selector_list->elements()).end(); ++__complex_selector) { Complex_Selector_Obj complex_selector = *(__complex_selector);
           Complex_Selector_Ptr tail = complex_selector;
@@ -141,6 +141,8 @@ namespace Sass {
       }
     }
 
+    // do not connect parent again
+    sel->remove_parent_selectors();
     selector_stack.push_back(sel);
     Env env(environment());
     if (block_stack.back()->is_root()) {
@@ -743,8 +745,14 @@ namespace Sass {
     Trace_Obj trace = SASS_MEMORY_NEW(Trace, c->pstate(), c->name(), trace_block);
 
 
+    if (Block_Ptr pr = block_stack.back()) {
+      trace_block->is_root(pr->is_root());
+    }
     block_stack.push_back(trace_block);
     for (auto __bb = (body->elements()).begin(); __bb != (body->elements()).end(); ++__bb) { auto bb = *(__bb);
+      if (Ruleset_Ptr r = Cast<Ruleset>(bb)) {
+        r->is_root(trace_block->is_root());
+      }
       Statement_Obj ith = bb->perform(this);
       if (ith) trace->block()->append(ith);
     }
