@@ -90,10 +90,13 @@ struct Sass_Inspect_Options {
   // Precision for fractional numbers
   int precision;
 
+  // Do not compress colors in selectors
+  bool in_selector;
+
   // initialization list (constructor with defaults)
   Sass_Inspect_Options(Sass_Output_Style style = Sass::NESTED,
-                       int precision = 5)
-  : output_style(style), precision(precision)
+                       int precision = 5, bool in_selector = false)
+  : output_style(style), precision(precision), in_selector(in_selector)
   { }
 
 };
