@@ -2,20 +2,16 @@ require 'pathname'
 
 # This represents a specific test case.
 class SassSpec::TestCase
+  attr_reader :folder, :input_path, :expected_path, :error_path, :status_path,
+              :options_path, :metadata
+
   def initialize(folder, options = {})
-    @folder = File.expand_path(folder)
+    @options = options
+    @folder = folder
     @metadata = SassSpec::TestCaseMetadata.new(folder, File.expand_path(options[:spec_directory]))
     @input_path = Pathname.new(find_input_path(folder))
-    @expected_path = File.join(folder, "expected_output.css")
-    @error_path = File.join(folder, "error")
-    @status_path = File.join(folder, "status")
     @options_path = File.join(folder, "options.yml")
-    @options = options
     @result = false
-
-    # Probe filesystem once and cache the results
-    @should_fail = File.file?(@status_path)
-    @verify_stderr = File.file?(@error_path)
   end
 
   def find_input_path(folder)
@@ -36,14 +32,50 @@ class SassSpec::TestCase
     @result = result
   end
 
-  def folder
-    @folder
-  end
-
   def name
     @metadata.name
   end
 
+  def folder
+    File.expand_path(@folder)
+  end
+
+  def expected_path
+    @expected_path ||= _expectation_path("expected_output.css")
+  end
+
+  def base_expected_path
+    File.join(@folder, "expected_output.css")
+  end
+
+  def impl_expected_path
+    File.join(@folder, "expected_output-#{impl}.css")
+  end
+
+  def error_path
+    @error_path ||= _expectation_path("error")
+  end
+
+  def base_error_path
+    File.join(@folder, "error")
+  end
+
+  def impl_error_path
+    File.join(@folder, "error-#{impl}")
+  end
+
+  def status_path
+    @status_path ||= _expectation_path("status")
+  end
+
+  def base_status_path
+    File.join(@folder, "status")
+  end
+
+  def impl_status_path
+    File.join(@folder, "status-#{impl}")
+  end
+
   def precision
     @metadata.precision || 5
   end
@@ -56,40 +88,24 @@ class SassSpec::TestCase
     @metadata.output_style
   end
 
-  def input_path
-    @input_path
-  end
-
-  def expected_path
-    @expected_path
-  end
-
-  def error_path
-    @error_path
-  end
-
-  def status_path
-    @status_path
-  end
-
-  def options_path
-    @options_path
-  end
-
   def verify_stderr?
-    @verify_stderr
+    !expected_error.empty?
   end
 
   def interactive?
     @options[:interactive]
   end
 
-  def migrate?
-    @options[:migrate]
+  def migrate_version?
+    @options[:migrate_version]
+  end
+
+  def migrate_impl?
+    @options[:migrate_impl]
   end
 
   def should_fail?
-    @should_fail
+    expected_status != 0
   end
 
   def impl
@@ -102,7 +118,7 @@ class SassSpec::TestCase
 
   def probe_todo?
     # run todo tests but do not fail runner if one does not pass
-    @options[:probe_todo] && (todo? || warning_todo?) && !interactive?
+    @options[:probe_todo] && (todo? || warning_todo?)
   end
 
   def warning_todo?
@@ -117,10 +133,6 @@ class SassSpec::TestCase
     @metadata.ignore_warning_for?(impl)
   end
 
-  def metadata
-    @metadata
-  end
-
   def overwrite?
     @options[:generate]
   end
@@ -151,7 +163,7 @@ class SassSpec::TestCase
   end
 
   def expected
-    output = File.read(@expected_path, :binmode => true, :encoding => "ASCII-8BIT")
+    output = File.read(expected_path, :binmode => true, :encoding => "ASCII-8BIT")
     # we seem to get CP850 otherwise
     # this provokes equal test to fail
     output.force_encoding('ASCII-8BIT')
@@ -163,12 +175,13 @@ class SassSpec::TestCase
   end
 
   def expected_error
-    @expected_error ||= if File.file?(@error_path)
-                          _clean_error(File.read(@error_path, :binmode => true,
-                                                 :encoding => "ASCII-8BIT"))
-                        else
-                          ""
-                        end
+    @expected_error ||=
+      if File.file?(error_path)
+        _clean_error(File.read(error_path, :binmode => true,
+                               :encoding => "ASCII-8BIT"))
+      else
+        ""
+      end
   end
 
   def equivalent?(other_test_case)
@@ -176,17 +189,26 @@ class SassSpec::TestCase
   end
 
   def expected_status
-    if should_fail?
-      @expected_status = File.read(@status_path).to_i
-    else
-      @expected_status = 0
-    end
+    @expected_status ||=
+      if File.file?(status_path)
+        @expected_status = File.read(status_path).to_i
+      else
+        @expected_status = 0
+      end
   end
 
   def engine
     @options[:engine_adapter]
   end
 
+  def _expectation_path(basename)
+    extension = File.extname(basename)
+    path = File.join(@folder, File.basename(basename, extension))
+
+    impl_path = "#{path}-#{impl}#{extension}"
+    File.file?(impl_path) ? impl_path : "#{path}#{extension}"
+  end
+
   # normalization happens for every test
   def _norm_output(css)
     # we dont want to test for linux or windows line-feeds
